.. _source:


.. raw:: html

    </center>
    <br>

.. title:: Source


.. raw:: html

    <center><b>SOURCE</b></center>
    <br>


**GENOCIDE**


.. autosummary::
    :toctree: 
    :template: base.rst


    genocide.broker		list of bots
    genocide.client		clients
    genocide.disk		storage
    genocide.find		locate
    genocide.handler		event handler
    genocide.log		logging
    genocide.object		clean namespace
    genocide.run		runtime
    genocide.thread		threads


**MODULES**


.. autosummary::
    :toctree: 
    :template: base.rst

    genocide.modules.cmd	list of commands
    genocide.modules.err	show errors
    genocide.modules.irc	internet realy chat
    genocide.modules.log	log text
    genocide.modules.mod	list of modules
    genocide.modules.req	request
    genocide.modules.rss	rich site syndicate
    genocide.modules.tdo	todo items
    genocide.modules.thr	list of threads
    genocide.modules.tmr	timers
